.. -*- coding: utf-8 -*-
.. :Progetto:  SoL
.. :Creato:    mer 09 lug 2014 10:12:29 CEST
.. :Autore:    Lele Gaifax <lele@metapensiero.it>
.. :Licenza:   GNU General Public License version 3 or later
..

Entities
========

.. toctree::
   :maxdepth: 2

   championships
   clubs
   competitors
   matches
   mergedplayers
   players
   rates
   ratings
   tourneys
